# Plotting Wand

Plot experimental results.

This project mainly uses [Plotly](https://plot.ly/python/) configurations and have limited compatibility with [Seaborn](https://seaborn.pydata.org/index.html).

![subplots/plot_line_plotly.py.png](https://github.com/elsa-lab/plotting-wand/raw/master/examples/subplots/images/plot_line_plotly.py.png)

## Features

* Friendly API interface
* Plotting examples

## Prerequisites

1. Linux-based terminals (For Windows, I recommend using [git-sdk](https://github.com/git-for-windows/build-extra/releases))
2. Python 3.5 or higher
3. [Orca](https://github.com/plotly/orca) (For saving image when plotting with Plotly)

## Installation

Run the following command:

```bash
pip install elsa-plotting-wand
```

## Examples

To get started, see the example [Minimalist](https://github.com/elsa-lab/plotting-wand/tree/master/examples/minimalist). For practical usage, see the example [Subplots](https://github.com/elsa-lab/plotting-wand/tree/master/examples/subplots).
